@@ -290,8 +290,7 @@ places_cfg_set_property (GObject      *object,
       text = g_value_get_string (value);
       if (strcmp(cfg->label, text))
         {
-          if (cfg->label != NULL)
-            g_free (cfg->label);
+          g_free (cfg->label);
           cfg->label = g_value_dup_string (value);
           g_signal_emit (G_OBJECT (cfg), places_cfg_signals[BUTTON_CHANGED], 0);
         }
@@ -364,8 +363,7 @@ places_cfg_set_property (GObject      *object,
       text = g_value_get_string (value);
       if (strcmp(cfg->search_cmd, text))
         {
-          if (cfg->search_cmd != NULL)
-            g_free (cfg->search_cmd);
+          g_free (cfg->search_cmd);
           cfg->search_cmd = g_value_dup_string (value);
           g_signal_emit (G_OBJECT (cfg), places_cfg_signals[MENU_CHANGED], 0);
         }
@@ -396,7 +394,7 @@ pcfg_make_empty_dialog(PlacesCfg *cfg)
     dlg = xfce_titled_dialog_new_with_mixed_buttons(_("Places"),
               NULL,
               GTK_DIALOG_DESTROY_WITH_PARENT,
-              "gtk-close", _("Close"), GTK_RESPONSE_ACCEPT, NULL);
+              "window-close-symbolic", _("Close"), GTK_RESPONSE_ACCEPT, NULL);
 
     gtk_window_set_position(GTK_WINDOW(dlg), GTK_WIN_POS_CENTER);
     gtk_window_set_icon_name(GTK_WINDOW(dlg), "xfce4-settings");
